﻿namespace UltraDayViewDisabledTimeSlots
{
    using System;
    using System.Drawing;
    using System.Windows.Forms;
    using Infragistics.Win.UltraWinSchedule;

    public partial class Form1 : Form
    {
        public const int DisabledStartHour = 0;
        public const int DisabledEndtHour = 8;

        public Form1()
        {
            this.InitializeComponent();
            this.Load += Form1_Load;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraDayView1.CalendarInfo = this.ultraCalendarInfo1;
            this.ultraDayView1.BeforeTimeSlotSelectionChanged += this.UltraDayView1_BeforeTimeSlotSelectionChanged;
            this.ultraCalendarInfo1.BeforeDisplayAppointmentDialog += this.UltraCalendarInfo1_BeforeDisplayAppointmentDialog;
            this.SetDisabledAppearance(DisabledStartHour, DisabledEndtHour);
        }

        /// <summary>
        /// Sets the appearance of each timeslot in the passed interval from <paramref name="startHour"/>
        /// to <paramref name="endHour"/>
        /// </summary>
        /// <param name="startHour">Disabled timeslots interval start time</param>
        /// <param name="endHour">Disabled timeslots interval end time</param>
        private void SetDisabledAppearance(int startHour, int endHour)
        {
            var disabledAppearance = new Infragistics.Win.Appearance();
            disabledAppearance.BackColor = Color.Gray;
            disabledAppearance.ForeColor = Color.DarkGray;
            foreach (var timeSlot in this.ultraDayView1.TimeSlots)
            {
                if (startHour <= timeSlot.StartTime.Hour && timeSlot.EndTime.Hour < endHour)
                {
                    timeSlot.ResetNonWorkingHourAppearance();
                    timeSlot.ResetWorkingHourAppearance();

                    timeSlot.WorkingHourAppearance = disabledAppearance;
                    timeSlot.NonWorkingHourAppearance = disabledAppearance;
                }
            }
        }

        /// <summary>
        /// Cancels the selection of the new time slot is in the disabled interval
        /// </summary>
        private void UltraDayView1_BeforeTimeSlotSelectionChanged(object sender, BeforeTimeSlotSelectionChangedEventArgs e)
        {
            if (DisabledStartHour <= e.NewSelectedTimeSlotRange.StartDateTime.Hour &&
                e.NewSelectedTimeSlotRange.EndDateTime.Hour < DisabledEndtHour)
            {
                e.Cancel = true;
            }
        }

        /// <summary>
        /// Cancels adding of new appointment of the time slot is in the disabled interval
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void UltraCalendarInfo1_BeforeDisplayAppointmentDialog(object sender, DisplayAppointmentDialogEventArgs e)
        {
            if (DisabledStartHour <= e.Appointment.StartDateTime.Hour &&
                e.Appointment.StartDateTime.Hour < DisabledEndtHour)
            {
                e.Cancel = true;
            }
        }
    }
}
